OC.L10N.register(
    "core",
    {
    "Please select a file." : "Prosím, vyberte súbor.",
    "File is too big" : "Súbor je príliš veľký",
    "The selected file is not an image." : "Vybraný súbor nie je obrázok.",
    "The selected file cannot be read." : "Vybraný súbor nie je možné čítať.",
    "Invalid file provided" : "Zadaný neplatný súbor",
    "No image or file provided" : "Obrázok alebo súbor nebol zadaný",
    "Unknown filetype" : "Neznámy typ súboru",
    "Invalid image" : "Chybný obrázok",
    "An error occurred. Please contact your admin." : "Vyskytla sa chyba.\nProsím, kontaktujte svojho správcu.\n\t",
    "No temporary profile picture available, try again" : "Dočasný profilový obrázok nie je k dispozícii, skúste to znovu",
    "No crop data provided" : "Dáta pre orezanie neboli zadané",
    "No valid crop data provided" : "Neplatné dáta pre orezanie neboli zadané",
    "Crop is not square" : "Orezanie nie je štvorcové",
    "State token does not match" : "Príznak stavu nesúhlasí",
    "Could not complete login" : "Nie je možné dokončiť prihlásenie",
    "Your login token is invalid or has expired" : "Váš prihlasovací token je neplatný alebo jeho platnosť skončila",
    "Password reset is disabled" : "Obnovenie hesla nie je povolené",
    "Couldn't reset password because the token is invalid" : "Nepodarilo sa obnoviť heslo, pretože token nie je platný",
    "Couldn't reset password because the token is expired" : "Nepodarilo sa obnoviť heslo, pretože platnosť tokenu uplynula",
    "%s password reset" : "reset hesla %s",
    "Password reset" : "Obnovenie hesla",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Pre obnovenie hesla kliknite na nasledujúce tlačidlo. Pokiaľ ste nevyžiadali obnovenie hesla, tento email ignorujte.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Pre obnovenie hesla kliknite na nasledujúci odkaz. Pokiaľ ste nevyžiadali obnovenie hesla, tento email ignorujte.",
    "Reset your password" : "Vytvoriť nové heslo",
    "Nextcloud Server" : "Nextcloud Server",
    "Some of your link shares have been removed" : "Niektoré odkazy sprístupnenia boli odstránené.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvôli bezpečnostnej chyba sme museli odstrániť niektoré z vašich odkazov pre sprístupnenie. Pre viac informácií nasledujte tento link.",
    "Preparing update" : "Pripravuje sa aktualizácia",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Krok opravy:",
    "Repair info:" : "Informácie o oprave:",
    "Repair warning:" : "Varovanie o oprave:",
    "Repair error:" : "Chyba opravy:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Automatická aktualizácia je zakázaná v config.php, použite prosím aktualizáciu cez príkazový riadok.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrola tabuľky %s",
    "Turned on maintenance mode" : "Mód údržby je zapnutý",
    "Turned off maintenance mode" : "Mód údržby je vypnutý",
    "Maintenance mode is kept active" : "Režim údržby je stále aktívny",
    "Updating database schema" : "Aktualizuje sa schéma databázy",
    "Updated database" : "Databáza je aktualizovaná",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Kontroluje sa, či je možné aktualizovať schému databázy (to môže trvať dlhší čas v závislosti na veľkosti databázy)",
    "Checked database schema update" : "Skontrolovať aktualizáciu schémy databázy",
    "Checking updates of apps" : "Kontrolujú sa aktualizácie aplikácií",
    "Checking for update of app \"%s\" in appstore" : "Hľadá sa aktualizácia aplikácie \"%s\" v obchode",
    "Update app \"%s\" from appstore" : "Aktualizovať aplikáciu \"%s\" z obchodu",
    "Checked for update of app \"%s\" in appstore" : "Hľadá sa aktualizácia aplikácie \"%s\" v obchode",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontroluje sa, či je možné aktualizovať schému databázy pre %s (to môže trvať dlhší čas v závislosti na veľkosti databázy)",
    "Checked database schema update for apps" : "Aktualizácia schémy databázy aplikácií bola overená",
    "Updated \"%1$s\" to %2$s" : "Aktualizované \"%1$s\" na %2$s",
    "Set log level to debug" : "Nastaviť úroveň záznamu na ladenie",
    "Reset log level" : "Obnoviť úroveň záznamu",
    "Starting code integrity check" : "Začína kontrola integrity kódu",
    "Finished code integrity check" : "Kontrola integrity kódu ukončená",
    "%s (incompatible)" : "%s (nekompatibilná)",
    "Following apps have been disabled: %s" : "Nasledovné aplikácie boli zakázané: %s",
    "Already up to date" : "Už aktuálne",
    "Very weak password" : "Veľmi slabé heslo",
    "Weak password" : "Slabé heslo",
    "So-so password" : "Priemerné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Silné heslo",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Váš webový server nie je zatiaľ správne nastavený, aby umožnil synchronizáciu súborov, pretože rozhranie WebDAV sa zdá byť nefunkčné.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Váš webový server nie je správne nastavený na spracovanie \"{url}\". Viac informácií môžete nájsť v našej <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácii</a>.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation page</a>. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Váš web server nie je správne nastavený, aby preložil \"{url}\". To pravdepodobne súvisí s nastavením webového servera, ktoré nebolo aktualizované pre priame doručovanie tohto priečinka. Porovnajte prosím svoje nastavenia voči dodávaným rewrite pravidlám v \".htaccess\" pre Apache alebo tým, ktoré uvádzame v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácii</a> pre Nginx. Tam je typicky potrebné aktualizovať riadky začínajúce na \"location ~\".",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Váš server nie je správne nastavený tak, aby doručoval súbory .woff2. Toto je typicky problém s nastavením Nginx. Pre Nextcloud 15 je potrebné ho upraviť, aby tieto súbory doručoval. Porovnajte nastavenie svojho Nginx s tým, ktorý je odporúčaný v našej <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácii</a>.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Zdá sa že PHP nie je nastavené korektne na získanie premenných prostredia.  Test s príkazom getenv(\"PATH\") vráti prázdnu odpoveď.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Prosím skontrolujte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">inštalačnú dokumentáciu</a>ohľadne PHP konfigurácie a PHP konfiguráciu Vášho servra, hlavne ak používate php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurácia je nastavená len na čítanie. Toto znemožňuje urobiť niektoré nastavenia prostredníctvom webového rozhrania. Okrem toho, súbor musí mať zapisovanie ručne povolené pre každú aktualizáciu.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaša databáza nebeží s úrovňou izolácie transakcií \"READ COMMITTED\".  Toto môže spôsobovať problémy v prípade ak viacero akcií beží paralelne.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Chýba PHP modul 'fileinfo'. Dôrazne doporučujeme ho povoliť pre dosiahnutie najlepších výsledkov zisťovania MIME-typu.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "Tranzakčné uzamykanie súborov je vypnuté, toto môže viesť k problémom.  Nastavte \"filelocking.enabled\" v config.php.  Viac informácií viď <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácia</a>.",
    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "Inštalácia mimo koreňový priečinok domény a používanie systémového príkazu cron môže spôsobiť problém s generovaním správnej URL. Pre zabránenie týmto chybám nastavte prosím správnu cestu v svojom config.php súbore pre hodnotu \"overwrite.cli.url\" (Doporučujeme: \"{suggestedOverwriteCliURL}\")",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nebolo možné spustiť cron úlohu na pozadí pomocou CLI.  Toto sú chyby:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "Úloha na pozadí naposledy prebehla {relativeTime}. Zdá sa, že niečo nie je v poriadku.",
    "Check the background job settings" : "Skontrolujte nastavenie úloh na pozadí",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Server nemá funkčné pripojenie k internetu. Niektoré moduly ako napr. externé úložisko, oznámenie o dostupných aktualizáciách alebo inštalácia aplikácií tretích strán nebudú fungovať. Vzdialený prístup k súborom a odosielanie oznamovacích emailov tiež nemusí fungovať. Ak chcete využívať všetky funkcie, odporúčame povoliť tomuto serveru pripojenie k internetu.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Nie je nakonfigurovaná vyrovnávacia pamäť. Ak chcete zvýšiť výkon, nakonfigurujte prosím memcache ak je to možné. Viac informácií nájdete v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácii</a>.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Použiteľný zdroj náhodnosti pre PHP nebol nájdený, čo nie je odporúčané z bezpečnostných dôvodov.  Viac informácií nájdete v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácii</a>.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Aktuálne používate PHP {version}. Dôrazne odporúčame prechod na vyššiu verziu ihneď, ako to vaša distribúcia dovolí, aby ste využili <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">všetky výkonnostné a bezpečnostné možnosti novej verzie PHP</a> od PHP Group.",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Aktuálne používate PHP 5.6. Aktuálne verzia Nextcloud podporuje verziu PHP 5.6, ale odporúčame upgrade na PHP verzie 7.0 a vyššej pre upgrade na Nextcloud 14",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Konfigurácia hlavičiek reverse proxy nie je správna alebo pristupujete k NextCloud z dôveryhodného proxy servera. Ak k Nextcloud nepristupujete z dôveryhodného proxy servera, vzniká bezpečnostné riziko - IP adresa potenciálneho útočníka, ktorú vidí Nextcloud, môže byť falošná. Viac informácií nájdete v našej <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácii</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached je nakonfigurovaný ako distribuovaná vyrovnávacia pamäť, ale v PHP je nainštalovaný nesprávny modul - \"memcache\". \\OC\\Memcache\\Memcached podporuje len modul \"memcached\", \"memcache\" nie je podporovaný. Viac informácií nájdete na <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki stránke o oboch moduloch</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Niektoré zo súborov neprešli kontrolou integrity. Viac informácii, aku napraviť túto situáciu, nájdete v našej <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácii</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Zobraziť zoznam podozrivých súborov</a> / <a href=\"{rescanEndpoint}\">Verifikovať znovu..</a>)",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "PHP modul OPcache nie je načítaný. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Pre zvýšenie výkonu ho odporúčame</a> zahrnúť do Vašej PHP inštalácie.",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP OPcache nie je nakonfigurovaná správne. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Pre zvýšenie výkonu</a> použite v <code>php.ini</code> nasledovné odporúčané nastavenia:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcia PHP \"set_time_limit\" nie je k dispozícii. To by mohlo viesť k zastaveniu skriptov v polovici vykonávania, čím by došlo k prerušeniu inštalácie. Dôrazne odporúčame povoliť túto funkciu.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vaše PHP nemá podporu FreeType, čo bude mať za následok poškodenie profilových obrázkov a rozhrania nastavení.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Chýbajúci index \"{indexName}\" v tabuľke \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "V databáze chýbajú nejaké indexy. Keďže pridávanie indexov voči veľkým tabuľkám môže trvať dlho, tak neboli pridané automaticky. Spustením príkazu \"occ db:add-missing-indices\" môžete tieto chýbajúce indexy pridať ručne počas behu. Akonáhle budú indexy aktívne, tak požiadavky voči databáze budú podstatne rýchlejšie.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "V tejto inštancii chýbajú niektoré odporúčané moduly PHP.\nAk chcete zlepšiť výkon a kompatibilitu, dôrazne odporúčame, aby ste ich nainštalovali.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Niektorým stĺpcom v databáze chýba konverzia na big int. Vzhľadom k tomu, že zmena typov stĺpcov na veľkých tabuľkých môže trvať dlhšie, neboli pri aktualizácii zmenené. Spustením príkazu 'occ db:convert-filecache-bigint' budú tieto nevybavené zmeny aplikované ručne. Táto operácia musí byť vykonaná v čase keď je inštancia offline. Ďalšie podrobnosti na <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">stránke dokumentácie</a>.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Ako databáza je použitá SQLite. Pre väčšie inštalácie odporúčame prejsť na inú databázu.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Toto odporúčame najmä pri používaní klientských aplikácií na synchronizáciu s desktopom.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "Pre migráciu na inú databázu použite príkaz: 'occ db:convert-type', alebo viď <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácia</a>.",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Použitie PHP interného mailera už nie je podporované. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Prosím aktualizujte nastavenie Vášho email servra<a/>.",
    "The PHP memory limit is below the recommended value of 512MB." : "Limit pre pamäť PHP je nižší ako odporúčaná hodnota 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Niektoré aplikačné priečinky majú iného vlastníka ako web server.  Toto môže nastať ak aplikácie boli inštalované manuálne.  Skontrolujte práva nasledovných priečinkov nasledovných aplikácií:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Ako databáza sa používa MySQL, ale nepodporuje 4-bajtové znaky. Aby vbolo možné také znaky (ako napr. emoji) bez problémov spracovať, odporúčame povoliť v MySQL podporu pre 4-bajtové znaky. Viac o tejto problematike nájdete v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácii</a>.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Táto inštancia používa ako hlavné úložisko objektové úložisko, ktoré je založené na protokole S3. Nahrávané súbory sú však dočasne ukladané priamo na server a preto odporúčame mať v PHP adresári pre dočasné súbory aspoň 50 GB voľného priestoru. Podrobnosti o umiestnení a priestore, ktorý je k dispozícii nájdete v logoch. Zmenu adresára pre dočasné súbory môžete uskutočniť v php.ini alebo zvýšte kapacitu súčasného umiestnenia.",
    "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Váš priečinok s dátami aj vaše súbory sú pravdepodobne prístupné z internetu. Súbor .htaccess nefunguje. Dôrazne odporúčame nakonfigurovať webový server tak, aby priečinok s dátami nebol naďalej prístupný alebo presunúť priečinok s dátami mimo priestoru, ktorý webový server sprístupňuje.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP \"{header}\" nie je nakonfigurovaná tak, aby sa rovnala \"{expected}\". Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP \"{header}\" nie je nakonfigurovaná tak, aby sa rovnala \"{expected}\". Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP \"{header}\" neobsahuje \"{expected}\". Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP hlavička \"{header}\" nie je nastavená na \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" alebo \"{val5}\". Môže to spôsobiť únik referer informácie. Pozrite si <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C odporúčania</a>.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "Hlavička HTTP \"Strict-Transport-Security\" nie je nakonfigurovaná aspoň na \"{seconds}\" sekúnd. Pre zvýšenie bezpečnosti odporúčame povoliť HSTS tak, ako je to popísané v našich <a href=\"{docUrl}\" rel=\"noreferrer noopener\">bezpečnostných tipoch</a>.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Stránku ste načítali cez nezabezpečene spojenie pomocou protokolu HTTP. Dôrazne sa odporúča nastaviť server tak, aby vyžadoval zabezpečené spojenie pomocou protokolu HTTPS. Viac sa dočítate v bezpečnostných tipoch <a href=\"{docUrl}\"> ↗</a>.",
    "Non-existing tag #{tag}" : "Neexistujúca značka #{tag}",
    "restricted" : "obmedzený",
    "invisible" : "neviditeľný",
    "({scope})" : "({scope})",
    "Delete" : "Zmazať",
    "Rename" : "Premenovať",
    "Collaborative tags" : "Kolaboratívne značky",
    "No tags found" : "Štítky sa nenašli",
    "unknown text" : "neznámy text",
    "Hello world!" : "Ahoj svet!",
    "sunny" : "slnečno",
    "Hello {name}, the weather is {weather}" : "Dobrý deň {name}, počasie je {weather}",
    "Hello {name}" : "Vitaj {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto sú výsledky vášho vyhľadávania <script>alert(1)</script></strong>",
    "new" : "nový",
    "_download %n file_::_download %n files_" : ["stiahnuť %n súbor","stiahnuť %n súbory","stiahnuť %n súborov","stiahnuť %n súborov"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Aktualizácie prebieha. V niektorých prostrediach môže opustenie tejto stránky spôsobiť prerušenie aktualizácie.",
    "Update to {version}" : "Aktualizuj na {version}",
    "An error occurred." : "Vyskytla sa chyba.",
    "Please reload the page." : "Obnovte prosím stránku.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizácia neprebehla úspešne. Pre viac informácií <a href=\"{url}\">navštívte príspevok na našom fóre</a>, ktorý pokrýva tento problém.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizácia bola neúspešná. Oznámte prosím tento problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunite Nextcloud</a>.",
    "Continue to Nextcloud" : "Pokračovať na Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Aktualizácia bola úspešná. Presmerúva sa na Nextcloud za %n sekundu.","Aktualizácia bola úspešná. Presmerúva sa na Nextcloud za %n sekundy.","Aktualizácia bola úspešná. Presmerúva sa na Nextcloud za %n sekúnd.","Aktualizácia bola úspešná. Presmerúva sa na Nextcloud za %n sekúnd."],
    "Searching other places" : "Prehľadanie ostatných umiestnení",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žiadne výsledky vyhľadávania v ostatných priečinkoch pre {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} výsledok vyhľadávania v ostatných priečinkoch","{count} výsledky vyhľadávania v ostatných priečinkoch","{count} výsledkov vyhľadávania v ostatných priečinkoch","{count} výsledkov vyhľadávania v ostatných priečinkoch"],
    "Server side authentication failed!" : "Autentifikácia na serveri zlyhala!",
    "Please contact your administrator." : "Kontaktujte prosím vášho administrátora.",
    "An internal error occurred." : "Došlo k vnútornej chybe.",
    "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
    "Username or email" : "používateľské meno alebo e-mail",
    "Username or\temail" : "Používateľské meno alebo \t email",
    "Password" : "Heslo",
    "Log in" : "Prihlásiť sa",
    "Logging in …" : "Prihlasujem ...",
    "Wrong username or password." : "Neprávne používateľské meno alebo heslo.",
    "User disabled" : "Používateľ zakázaný",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznamenali sme viacnásobné chybné prihlásenie z Vašej IP adresy. Vaše nasledujúce prihlásenie bude pozdržané o 30 sekúnd.",
    "Reset password" : "Obnovenie hesla",
    "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Správa s informáciami na zmenu hesla bola zaslaná na email uvedený v tomto účte. Ak tam nie je, skontrolujte si priečinok nevyžiadanej pošty a kôš, alebo požiadajte svojho administrátora o pomoc.",
    "If it is not there ask your local administrator." : "Ak tam nie je, pýtajte sa vášho lokálneho administrátora.",
    "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
    "Password can not be changed. Please contact your administrator." : "Heslo nemožno zmeniť. Kontaktujte prosím vášho administrátora.",
    "Back to login" : "Späť na prihlásenie",
    "New password" : "Nové heslo",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaše súbory sú šifrované. Po obnovení hesla nebude možné dostať sa k vašim údajom. Ak neviete, čo robíte, kontaktujte vášho administrátora a až potom pokračujte. Naozaj chcete pokračovať?",
    "I know what I'm doing" : "Viem, čo robím",
    "Resetting password" : "Obnovuje sa heslo",
    "Forgot password?" : "Zabudli ste heslo?",
    "Settings" : "Nastavenia",
    "Could not load your contacts" : "Nie je možné načítať Vaše kontakty",
    "Search contacts …" : "Prehľadať kontakty...",
    "No contacts found" : "Kontakty nenájdené",
    "Show all contacts …" : "Zobraziť všetky kontakty...",
    "Install the Contacts app" : "Inštalovaťa aplikáciu Kontakty",
    "Loading your contacts …" : "Otvárajú sa kontakty...",
    "Looking for {term} …" : "Hľadá sa výraz {term}...",
    "No" : "Nie",
    "Yes" : "Áno",
    "No files in here" : "Nie sú tu žiadne súbory",
    "New folder" : "Nový priečinok",
    "No more subfolders in here" : "Už tu nie sú žiadne ďalšie podpriečinky",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "{newName} already exists" : "{newName} už existuje",
    "Choose" : "Vybrať",
    "Copy" : "Kopírovať",
    "Move" : "Presunúť",
    "Error loading file picker template: {error}" : "Chyba pri nahrávaní šablóny výberu súborov: {error}",
    "OK" : "Ok",
    "Error loading message template: {error}" : "Chyba pri nahrávaní šablóny správy: {error}",
    "read-only" : "iba na čítanie",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} konflikt súboru","{count} konflikty súboru","{count} konfliktov súboru","{count} konfliktov súboru"],
    "One file conflict" : "Jeden konflikt súboru",
    "New Files" : "Nové súbory",
    "Already existing files" : "Už existujúce súbory",
    "Which files do you want to keep?" : "Ktoré súbory chcete ponechať?",
    "If you select both versions, the copied file will have a number added to its name." : "Ak zvolíte obe verzie, názov nakopírovaného súboru bude doplnený o číslo.",
    "Cancel" : "Zrušiť",
    "Continue" : "Pokračovať",
    "(all selected)" : "(všetko vybrané)",
    "({count} selected)" : "({count} vybraných)",
    "Error loading file exists template" : "Chyba pri nahrávaní šablóny existencie súboru",
    "Pending" : "Čaká",
    "Copy to {folder}" : "Skopírovať do {folder}",
    "Move to {folder}" : "Presunúť do {folder}",
    "Saving..." : "Ukladám...",
    "Authentication required" : "Vyžaduje sa overenie",
    "This action requires you to confirm your password" : "Táto akcia vyžaduje potvrdenie vášho hesla",
    "Confirm" : "Potvrdiť",
    "Failed to authenticate, try again" : "Nastal problém pri overení, skúste znova",
    "seconds ago" : "pred sekundami",
    "Connection to server lost" : "Stratené spojenie so serverom",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Nepodarilo sa načítať stránku, opätovný pokus o %n sekundu","Nepodarilo sa načítať stránku, opätovný pokus o %n sekundy","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd"],
    "Add to a project" : "Pridať do projektu",
    "Show details" : "Zobraziť podrobnosti",
    "Hide details" : "Skryť podrobnosti",
    "Rename project" : "Premenovať projekt",
    "Failed to rename the project" : "Nepodarilo sa premenovať projekt",
    "Failed to create a project" : "Nepodarilo sa vytvoriť projekt",
    "Failed to add the item to the project" : "Nepodarilo sa pridať položku do projektu",
    "Connect items to a project to make them easier to find" : "Priradiť položky do projektu, aby sa ľahšie hľadali",
    "Type to search for existing projects" : "Hľadajte v existujúcich projektoch",
    "New in" : "Nové v",
    "View changelog" : "Zobraziť súhrn zmien",
    "No action available" : "NIe sú dostupné žiadne akcie",
    "Error fetching contact actions" : "Chyba počas získavania akcií kontaktu",
    "Personal" : "Osobné",
    "Users" : "Používatelia",
    "Apps" : "Aplikácie",
    "Admin" : "Administrácia",
    "Help" : "Pomoc",
    "Access forbidden" : "Prístup odmietnutý",
    "File not found" : "Súbor nenájdený",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokument nebol nájdený na servri.  Je možné že zdieľanie bolo vymazané alebo expirovalo?",
    "Back to %s" : "Späť na %s",
    "Error" : "Chyba",
    "Internal Server Error" : "Vnútorná chyba servera",
    "The server was unable to complete your request." : "Server nebol schopný dokončiť vašu žiadosť.",
    "If this happens again, please send the technical details below to the server administrator." : "Ak sa to stane opäť, nižšie zašlite technické podrobnosti správcovi servera.",
    "More details can be found in the server log." : "Viac nájdete v logu servera.",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Vzdialená adresa: %s",
    "Request ID: %s" : "ID požiadavky: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kód: %s",
    "Message: %s" : "Správa: %s",
    "File: %s" : "Súbor: %s",
    "Line: %s" : "Riadok: %s",
    "Trace" : "Trasa",
    "Security warning" : "Bezpečnostné varovanie",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš priečinok s dátami a súbormi je dostupný z internetu, lebo súbor .htaccess nefunguje.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pre podrobnosti ako správne nakonfigurovať server si pozrite prosím <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentáciu</a>.",
    "Create an <strong>admin account</strong>" : "Vytvoriť <strong>administrátorský účet</strong>",
    "Username" : "Meno používateľa",
    "Storage & database" : "Úložisko & databáza",
    "Data folder" : "Priečinok dát",
    "Configure the database" : "Nastaviť databázu",
    "Only %s is available." : "Je dostupný len %s.",
    "Install and activate additional PHP modules to choose other database types." : "Pri výbere iného typu databázy bude potrebné nainštalovať a aktivovať ďalšie PHP moduly.",
    "For more details check out the documentation." : "Viac informácií nájdete v dokumentácii.",
    "Database user" : "Používateľ databázy",
    "Database password" : "Heslo databázy",
    "Database name" : "Meno databázy",
    "Database tablespace" : "Tabuľkový priestor databázy",
    "Database host" : "Server databázy",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadajte číslo portu spolu s názvom hostiteľa (napr. localhost:5432).",
    "Performance warning" : "Varovanie o výkone",
    "You chose SQLite as database." : "Ako databázu ste vybrali SQLite.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by sa malo používať len pre naozaj maličké alebo vývojové inštancie. Pre produkčné použitie výrazne odporúčame použiť robustnejšiu databázu.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ak používate klientské aplikácie pre synchronizáciu súborov, tak výrazne odporúčame nepoužívať SQLite.",
    "Finish setup" : "Dokončiť inštaláciu",
    "Finishing …" : "Dokončujem...",
    "Need help?" : "Potrebujete pomoc?",
    "See the documentation" : "Pozri dokumentáciu",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Vyzerá, že sa snažíte preinštalovať svoj Nextcloud. Avšak v adresári s konfiguráciou chýba súbor CAN_INSTALL. Ak chcete pokračovať, tak ho vytvorte.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nie je možné odstrániť súbor CAN_INSTALL z adresára s konfiguráciou. Je potrebné ho odstrániť ručne.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Táto aplikácia vyžaduje JavaScript, aby správne fungovala. Prosím, {linkstart}zapnite si JavaScript{linkend} a obnovte stránku",
    "Get your own free account" : "Získajte zdarma svoj vlastný účet",
    "Skip to main content" : "Prejsť na hlavný obsah",
    "Skip to navigation of app" : "Preskočiť do navigácie apky",
    "More apps" : "Viac aplikácií",
    "More" : "Viac",
    "More apps menu" : "Menu ostatných aplikácií",
    "Search" : "Hľadať",
    "Reset search" : "Vynuluj vyhľadávanie",
    "Contacts" : "Kontakty",
    "Contacts menu" : "Menu kontaktov",
    "Settings menu" : "Menu nastavení",
    "Confirm your password" : "Potvrďte svoje heslo",
    "Connect to your account" : "Pripojte sa k svojmu účtu",
    "Please log in before granting %1$s access to your %2$s account." : "Skôr než udelíte prístup pre %1$s do vášho účtu %2$s je potrebné sa prihlásiť.",
    "App token" : "Token aplikácie",
    "Grant access" : "Povoliť prístup",
    "Alternative log in using app token" : "Alternatívne prihlásenie pomocou tokenu aplikácie",
    "Account access" : "Prístup k účtu",
    "You are about to grant %1$s access to your %2$s account." : "Chystáte sa udeliť %1$s prístup k svojmu %2$s účtu.",
    "Account connected" : "Účet pripojený",
    "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
    "You can close this window." : "Toto okno už môžete zatvoriť.",
    "This share is password-protected" : "Toto sprístupnenie je chránené heslom",
    "The password is wrong. Try again." : "Heslo je chybné. Skúste to znova.",
    "Two-factor authentication" : "Dvojzložkové overovanie",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Vylepšená bezpečnosť je pre váš účet povolená. Vyberte druhý faktor overenia:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedá sa načíťať minimálne jeden z vašich povolených spôsobov na dvojzložkové overovanie. Kontaktujte prosím správcu systému.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dvojfaktorová autentifikácia je vyžadovaná ale nebola nakonfigurovaná pre Váš účet.  Kontaktujte administrátora pre ďalšiu asistenciu.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Vo vašom účte sa vynucuje dvojzložkové overovanie, ale ešte nebolo nakonfigurované. Pokračujte prosím do nastavenia dvojzložkového overovania.",
    "Set up two-factor authentication" : "Nastaviť dvojzložkové overovanie",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dvojfaktorová autentifikácia je vyžadovaná ale nebola nakonfigurovaná pre Váš účet.  Použite jeden zo záložných kódov na prihlásenie alebo kontaktujte administrátora pre ďalšiu asistenciu.",
    "Use backup code" : "Použiť záložný kód",
    "Cancel log in" : "Zrušiť prihlásenie",
    "Setup two-factor authentication" : "Nastaviť dvojzložkové overovanie",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Pre váš účet je vynútená zvýšená bezpečnosť. Vyberte si poskytovateľa, ktorého chcete nastaviť:",
    "Error while validating your second factor" : "Chyba počas overovania druhého faktora",
    "Access through untrusted domain" : "Prístup cez nedôveryhodnú doménu",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontaktujte svojho správcu. Ak ste administrátorom vy, upravte nastavenie \"trusted_domains\" v config/config.php ako napríklad v config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Viac informácií o konfigurácii je možné nájsť v %1$s dokumentácii %2$s.",
    "App update required" : "Je nutná aktualizácia aplikácie",
    "%1$s will be updated to version %2$s" : "%1$s bude zaktualizovaný na verziu %2$s.",
    "These apps will be updated:" : "Tieto aplikácie budú aktualizované:",
    "These incompatible apps will be disabled:" : "Tieto nekompatibilné aplikácie budú vypnuté:",
    "The theme %s has been disabled." : "Téma %s bola zakázaná.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred vykonaním ďalšieho kroku sa presvedčte, že databáza, konfiguračný a dátový priečinok sú zazálohované.",
    "Start update" : "Spustiť aktualizáciu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Aby nedošlo k vypršaniu časového limitu vo väčších inštaláciách, môžete namiesto toho použiť nasledujúci príkaz z inštalačného priečinka:",
    "Detailed logs" : "Podrobné záznamy",
    "Update needed" : "Aktualizácia je potrebná",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Použite aktualizátor z príkazového riadka, pretože máte veľkú inštanciu s viac ako 50 používateľmi.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pre pomoc si pozrite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentáciu</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Viem, že ak budem pokračovať v aktualizácii prostredníctvom webového rozhrania, existuje riziko, že žiadosť prekročí časový limit a môže spôsobiť stratu dát, ale mám zálohu a viem, ako obnoviť svoju inštanciu v prípade zlyhania.",
    "Upgrade via web on my own risk" : "Aktualizovať cez web na vlastné riziko",
    "Maintenance mode" : "Mód údržby",
    "This %s instance is currently in maintenance mode, which may take a while." : "Táto %s inštancia je v súčasnej dobe v režime údržby. Počkajte prosím.",
    "This page will refresh itself when the instance is available again." : "Táto stránka sa obnoví sama hneď ako bude inštancia znovu dostupná.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Nemožno poslať email pre obnovu, lebo pre zadaného používateľa neexistuje emailová adresa. Kontaktujte prosím vášho administrátora.",
    "Couldn't send reset email. Please make sure your username is correct." : "Nemožno poslať email pre obnovu. Uistite sa, či vkladáte správne používateľské meno.",
    "Dismiss" : "Odmietnuť",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovu hesla bol odoslaný na váš email. Pokiaľ ho neobdržíte v primeranom čase, skontrolujte spam / priečinok nevyžiadanej pošty. <br> Ak tam nie je, kontaktujte svojho administrátora.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vaše súbory sú zašifrované. Po zresetovaní vášho hesla nebude možné vaše dáta obnoviť.<br />Ak si nie ste istý, pred pokračovaním kontaktujte administrátora.<br />Skutočne si prajete pokračovať?",
    "Sending email …" : "Posielam email …",
    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} s verziou nižšou ako {version} nainštalovaný, z dôvodu stability a výkonu sa odporúča aktualizovať na novšiu {name} verziu.",
    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Prístup na túto stránku sa uskutočňuje prostredníctvom nezabezpečeného protokolu HTTP. Dôrazne odporúčame, aby ste namiesto toho nakonfigurovali server tak, aby vyžadoval použitie HTTPS, ako je to popísané v našich <a href=\"{docUrl}\">bezpečnostných tipoch</a>.",
    "Shared" : "Sprístupnené",
    "Shared with" : "Sprístupnené používateľovi",
    "Shared by" : "Sprístupnené používateľom",
    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
    "Choose a password for the public link or press the \"Enter\" key" : "Zvoľte heslo pre verejný link alebo stlačte klávesu \"Enter\"",
    "Copied!" : "Skopírované!",
    "Copy link" : "Kopíruj odkaz",
    "Not supported!" : "Nie je podporované!",
    "Press ⌘-C to copy." : "Stlač ⌘-C pre skopírovanie.",
    "Press Ctrl-C to copy." : "Stlač Ctrl-C pre skopírovanie.",
    "Unable to create a link share" : "Nie je možné vytvoriť odkaz pre sprístupnenie",
    "Unable to toggle this option" : "Túto voľbu nie je možné prepnúť",
    "Resharing is not allowed" : "Sprístupnenie už sprístupnenej položky nie je povolené",
    "Link" : "Odkaz",
    "Hide download" : "Skryť sťahovanie",
    "Password protection enforced" : "Vynútená ochrana heslom",
    "Password protect" : "Chrániť heslom",
    "Allow editing" : "Povoliť úpravy",
    "Email link to person" : "Odoslať odkaz emailom",
    "Send" : "Odoslať",
    "Allow upload and editing" : "Povoliť nahratie a úpravy",
    "Read only" : "Len na čítanie",
    "File drop (upload only)" : "Odovzdávanie súborov (len nahrávanie)",
    "Expiration date enforced" : "Vynútený dátum ukončenia platnosti",
    "Set expiration date" : "Nastaviť dátum expirácie",
    "Expiration" : "Koniec platnosti",
    "Expiration date" : "Dátum expirácie",
    "Note to recipient" : "Poznámka pre príjemcu",
    "Unshare" : "Zneprístupniť",
    "Delete share link" : "Zmazať sprístupnený odkaz",
    "Add another link" : "Pridať ďalší odkaz",
    "Password protection for links is mandatory" : "Ochrana heslom je pre odkazy povinná",
    "Share to {name}" : "Zdieľať s {name}",
    "Share link" : "Sprístupniť odkaz",
    "New share link" : "Nový odkaz na sprístupnenie",
    "Created on {time}" : "Vytvorené {time}",
    "Password protect by Talk" : "Chránené heslom apkou Talk",
    "Could not unshare" : "Nepodarilo sa zrušiť sprístupnenie",
    "Shared with you and the group {group} by {owner}" : "Sprístupnené vám a skupine {group} používateľom {owner}",
    "Shared with you and {circle} by {owner}" : "Sprístupnené vám a {circle} od {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Sprístupnené vám a rozhovoru {conversation} od {owner}",
    "Shared with you in a conversation by {owner}" : "Sprístupnené vám vrámci rozhovoru s {owner}",
    "Shared with you by {owner}" : "Sprístupnené vám používateľom {owner}",
    "Choose a password for the mail share" : "Zvoľte heslo pre zdieľanie pošty",
    "group" : "skupina",
    "remote" : "vzdialený",
    "remote group" : "vzdialená skupina",
    "email" : "E-mail",
    "conversation" : "rozhovor",
    "shared by {sharer}" : "zdieľal {sharer}",
    "Can reshare" : "Môže opätovne zdieľať",
    "Can edit" : "Môže upravovať",
    "Can create" : "Môže vytvárať",
    "Can change" : "Môže meniť",
    "Can delete" : "Môže odstraňovať",
    "Access control" : "Prístupové práva",
    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} zdieľal pomocou odkazu",
    "Error while sharing" : "Chyba počas sprístupňovania",
    "Share details could not be loaded for this item." : "Nebolo možné načítať údaje o sprístupnení tejto položky.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Najmenej {count} znak je potrebný pre autodopĺňanie","Najmenej {count} znaky sú potrebné pre autodopĺňanie","Najmenej {count} znakov je potrebných pre autodopĺňanie","Najmenej {count} znakov je potrebných pre autodopĺňanie"],
    "This list is maybe truncated - please refine your search term to see more results." : "Tento zoznam môže byť skrátený - upresnite hľadaný výraz, aby ste získali viac výsledkov.",
    "No users or groups found for {search}" : "Výrazu {search} nezodpovedá žiadny používateľ ani skupina",
    "No users found for {search}" : "Výrazu {search} nezodpovedá žiadny používateľ",
    "An error occurred (\"{message}\"). Please try again" : "Nastala chyba (\"{message}\"). Prosím, skúste znova",
    "An error occurred. Please try again" : "Nastala chyba. Skúste to prosím znovu",
    "Home" : "Domov",
    "Work" : "Práca",
    "Other" : "Iné",
    "{sharee} (remote group)" : "{sharee} (vzdialená skupina)",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Sprístupniť",
    "Name or email address..." : "Meno alebo e-mailová adresa...",
    "Name or federated cloud ID..." : "Meno alebo federatívny cloud ID...",
    "Name, federated cloud ID or email address..." : "Meno, federatívny cloud ID alebo e-mailová adresa...",
    "Name..." : "Meno...",
    "Error removing share" : "Chyba pri rušení sprístupnenia",
    "SQLite will be used as database." : "Bude použitá SQLite databáza.",
    "For larger installations we recommend to choose a different database backend." : "Pre veľké inštalácie odporúčame vybrať si iné databázové riešenie.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Najmä pri používaní klientských aplikácií na synchronizáciu s desktopom neodporúčame používať SQLite.",
    "Wrong password." : "Nesprávne heslo.",
    "New Password" : "Nové heslo",
    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovenie hesla bol odoslaný na e-mailovú adresu uvedenú pre tento účet. Ak ho v krátkej dobe neobdržíte, skontrolujte si priečinok nevyžiadanej pošty a kôš.<br>Ak ho nenájdete, kontaktujte svojho správcu systému.",
    "Search globally" : "Hľadať globálne",
    "Your client should now be connected! You can close this window." : "Váš klient by mal byť pripojený. Toto okno už môžete zatvoriť."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
